==> qmapshack_1.16.1.orig.tar.gz: qmapshack-V_1.16.1/src/qmapshack/realtime/gpstether/CRtGpsTether.h <==
/**********************************************************************************************
    Copyright (C) 2018 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CRTGPSTETHER_H
#define CRTGPSTETHER_H

#include "realtime/IRtSource.h"

#include <QPointer>

class CRtGpsTetherInfo;
class QGeoPositionInfoSource;
class QGeoPositionInfo;

class CRtGpsTether : public IRtSource
{
    Q_OBJECT
public:
    CRtGpsTether(QTreeWidget* parent);
    virtual ~CRtGpsTether() = default;

    void registerWithTreeWidget() override;

    QString getDescription() const override;
    void loadSettings(QSettings& cfg) override;
    void saveSettings(QSettings& cfg) const override;

    void drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>& blockedAreas, CRtDraw* rt) override;

    void fastDraw(QPainter& p, const QRectF& viewport, CRtDraw* rt) override;

    static const QString strIcon;

private:
    QPointer<CRtGpsTetherInfo> info;
};

#endif //CRTGPSTETHER_H

==> qmapshack_1.19.0.orig.tar.gz: qmapshack-V_1.19.0/src/qmapshack/realtime/gpstether/CRtGpsTether.h <==
/**********************************************************************************************
    Copyright (C) 2018 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CRTGPSTETHER_H
#define CRTGPSTETHER_H

#include <QPointer>

#include "realtime/IRtSource.h"

class CRtGpsTetherInfo;
class QGeoPositionInfoSource;
class QGeoPositionInfo;

class CRtGpsTether : public IRtSource {
  Q_OBJECT
 public:
  CRtGpsTether(QTreeWidget* parent);
  virtual ~CRtGpsTether() = default;

  void registerWithTreeWidget() override;

  QString getDescription() const override;
  void loadSettings(QSettings& cfg) override;
  void saveSettings(QSettings& cfg) const override;

  void drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>& blockedAreas, CRtDraw* rt) override;

  void fastDraw(QPainter& p, const QRectF& viewport, CRtDraw* rt) override;

  static const QString strIcon;

 private:
  QPointer<CRtGpsTetherInfo> info;
};

#endif  // CRTGPSTETHER_H
